@@ -134,33 +134,20 @@ id3_rva_get_adjust(id3_frame_t f, enum id3_rva_channel channel)
 
   /* cycle through fields */
   i++;
-  while (1) {
-
-    if (i >= f->sz)
-      break;
+  while (i + 3 < f->sz) {
 
     if (data[i] == (unsigned char)channel) {
-
       /* we found a field for the requested channel; decode it */
       adj_fp = *(signed char *)(data+i+1) << 8; /* first byte of adjustment */
-      adj_fp |= data[i+2];                      /* second byte of adjustment */
+      adj_fp |= *(unsigned char *)(data+i+2);   /* second byte of adjustment */
       adj = adj_fp / 512.0;
       break;
-
-    } else {
-
-      /* this field doesn't match the requested channel; skip it */
-      i += 3;
-      if (i >= f->sz)
-	break;
-      peakbytes = data[i] / 8;
-      i += peakbytes;
-
     }
 
-    i++;
-    if (i >= f->sz)
-      break;
+    /* this field doesn't match the requested channel; skip it */
+    i += 3;
+    peakbytes = (data[i] + 7) / 8;
+    i += 1 + peakbytes;
   }
 
   return adj;
@@ -246,7 +233,7 @@ id3_rva_set(id3_t tag, const char *ident,
 
     f->id3 = tag;
     strncpy(f->id, id, 4);
-    strcpy(f->data, ident);
+    strcpy((char *)f->data, ident);
     /* we later write the field starting at f->data + i */
     i = idlen + 1;
 
