@@ -1,10 +1,10 @@
-/* Copyright (C) 2001 Chris Vaill
+/* Copyright (C) 2001--2005 Chris Vaill
    This file is part of nid3lib.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -246,7 +246,7 @@ _convert_apic_forward(id3_frame_t f)
     return -1;
   }
   f->data[0] = data[0];
-  strcpy(f->data + 1, mimetype);
+  strcpy((char *)f->data + 1, mimetype);
   memcpy(f->data + 1 + i + 1, data + 4, f->sz - 4);
   f->sz = newsz;
   free(data);
@@ -276,7 +276,7 @@ _convert_apic_backward(id3_frame_t f)
     bad_mimetype = 1;
 
   if (!bad_mimetype) {
-    mimetype = data + 1;
+    mimetype = (char *)data + 1;
     len = strlen(mimetype);
     for (i = 0; i < len; i++)
       mimetype[i] = tolower(mimetype[i]);
@@ -338,7 +338,7 @@ _convert_time_backward(id3_frame_t f)
   old_data = id3_frame_get_raw(f);
   if (old_data == NULL)
     return 0;
-  len = strlen(old_data + 1);
+  len = strlen((char *)old_data + 1);
 
   if (len >= 4) {
     /* form TYER frame */
@@ -395,7 +395,7 @@ _convert_time_forward(id3_frame_t f)
     if (strcmp(f->id, "TDAT") == 0) {
 
       /* make sure the TIME frame is in the form DDMM */
-      if (strlen(old_data + 1) != 4) {
+      if (strlen((char *)old_data + 1) != 4) {
 	/* non-standard TDAT frame, so drop it */
 	return 1;
       }
@@ -403,14 +403,14 @@ _convert_time_forward(id3_frame_t f)
       f->data = (unsigned char *)calloc(f->sz + 2, 1);
       /* leave space for the year if we find a TYER later */
       /* (string is split to avoid trigraphs) */
-      sprintf(f->data + 1, "????" "-%c%c-%c%c",
+      sprintf((char *)f->data + 1, "????" "-%c%c-%c%c",
 	      old_data[3], old_data[4], old_data[1], old_data[2]);
       free(old_data);
 
     } else if (strcmp(f->id, "TIME") == 0) {
 
       /* make sure the TIME frame is in the form HHmm */
-      if (strlen(old_data + 1) != 4) {
+      if (strlen((char *)old_data + 1) != 4) {
 	/* non-standard TIME frame, so drop it */
 	return 1;
       }
@@ -418,7 +418,7 @@ _convert_time_forward(id3_frame_t f)
       f->data = (unsigned char *)calloc(f->sz + 2, 1);
       /* leave space for the year and date for later TYER and TDAT */
       /* (string is split to avoid trigraphs) */
-      sprintf(f->data + 1, "????" "-??" "-??T%c%c:%c%c",
+      sprintf((char *)f->data + 1, "????" "-??" "-??T%c%c:%c%c",
 	      old_data[1], old_data[2], old_data[3], old_data[4]);
       free(old_data);
 
@@ -436,7 +436,7 @@ _convert_time_forward(id3_frame_t f)
     if (strcmp(f->id, "TDAT") == 0) {
 
       /* make sure the TIME frame is in the form DDMM */
-      if (strlen(f->data + 1) != 4) {
+      if (strlen((char *)f->data + 1) != 4) {
 	/* non-standard TDAT frame, so drop it */
 	return 1;
       }
@@ -453,13 +453,13 @@ _convert_time_forward(id3_frame_t f)
 	tdrc_f->data[11] = tdrc_f->data[12] = '\0'; /* ensure termination */
       }
       /* data will now be YYYY-MM-DD, so splice in the -MM-DD */
-      sprintf(tdrc_f->data + 5, "-%c%c-%c%c",
+      sprintf((char *)tdrc_f->data + 5, "-%c%c-%c%c",
 	      f->data[3], f->data[4], f->data[1], f->data[2]);
 
     } else if (strcmp(f->id, "TIME") == 0) {
 
       /* make sure the TIME frame is in the form HHmm */
-      if (strlen(f->data + 1) != 4) {
+      if (strlen((char *)f->data + 1) != 4) {
 	/* non-standard TIME frame, so drop it */
 	return 1;
       }
@@ -476,13 +476,13 @@ _convert_time_forward(id3_frame_t f)
 	tdrc_f->data[17] = tdrc_f->data[18] = '\0'; /* ensure termination */
       }
       /* data will now be YYYY-MM-DDTHH:mm, so splice in the THH:mm */
-      sprintf(tdrc_f->data + 11, "T%c%c:%c%c",
+      sprintf((char *)tdrc_f->data + 11, "T%c%c:%c%c",
 	      f->data[1], f->data[2], f->data[3], f->data[4]);
 
     } else if (strcmp(f->id, "TYER") == 0) {
 
       /* make sure the TYER frame is in the form YYYY */
-      if (strlen(f->data + 1) != 4) {
+      if (strlen((char *)f->data + 1) != 4) {
 	/* non-standard TYER frame, so drop it */
 	return 1;
       }
@@ -527,7 +527,7 @@ convert_time(id3_frame_t f, const char *from, const char *to, int backward)
 static int
 convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
 {
-  unsigned char *src, *dest, *rparen;
+  char *src, *dest, *rparen;
   unsigned char *data;
   char *endptr;
   int i, newsz, len, last_was_nonnumeric;
@@ -556,11 +556,11 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
       return -1;
     }
 
-    src = data;
-    dest = f->data;
+    src = (char *)data;
+    dest = (char *)f->data;
     *dest++ = *src++; /* text encoding byte */
     last_was_nonnumeric = 0;
-    while (src - data < f->sz) {
+    while (src - (char *)data < f->sz) {
 
       /* Check for a numeric string between 0 and 255, by itself */
       if (src[0] >= '0' && src[0] <= '9') { 
@@ -586,7 +586,7 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
       src++; /* skip the '\0' */
       last_was_nonnumeric = 1;
     }
-    newsz = dest - f->data;
+    newsz = dest - (char *)f->data;
     free(data);
 
   } else {
@@ -594,8 +594,8 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
     /* "(129)(9)" ==> "129" 0x00 "9" 0x00 */
     /* "(129)((I think)" ==> "129" 0x00 "(I think)" 0x00 */
 
-    src = dest = data + 1;
-    while (src - data < f->sz) {
+    src = dest = (char *)data + 1;
+    while (src - (char *)data < f->sz) {
 
       if (src[0] == '(') {
 
@@ -606,7 +606,7 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
 	  if (rparen)
 	    len = rparen - src + 1;
 	  else
-	    len = f->sz - (src - data);
+	    len = f->sz - (src - (char *)data);
 	  memmove(dest, src, len);
 	  src += len;
 	  dest += len;
@@ -630,7 +630,7 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
       }
     }
 
-    newsz = dest - data;
+    newsz = dest - (char *)data;
   }
 
   f->sz = newsz;
