@@ -1,10 +1,10 @@
-/* Copyright (C) 2001 Chris Vaill
+/* Copyright (C) 2001--2005 Chris Vaill
    This file is part of nid3lib.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 /*
  * This file contains a single externally visible function,
@@ -59,15 +59,6 @@
 #if HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
-#if HAVE_BYTESWAP_H
-# include <byteswap.h>
-#else
-# define bswap_16(x) \
-    ((((x) >> 8) & 0xff) | (((x) & 0xff) << 8))
-# define bswap_32(x) \
-    ((((x) & 0xff000000) >> 24) | (((x) & 0x00ff0000) >>  8) |       \
-     (((x) & 0x0000ff00) <<  8) | (((x) & 0x000000ff) << 24))
-#endif /* HAVE_BYTESWAP_H */
 #if HAVE_FTRUNCATE
 /*
  * ftruncate() shouldn't be declared yet, since we turn on
@@ -81,6 +72,12 @@ int ftruncate();
 
 #define USE_TEMPFILE 1
 
+#ifdef HAVE_DOS_FILE_NAMES
+# define SLASH_CHAR '\\'
+#else
+# define SLASH_CHAR '/'
+#endif
+
 static int xrename(const char *oldpath, const char *newpath);
 static int xmkstemp(char *template);
 
@@ -429,7 +426,7 @@ _write_v3_frames(id3_t tag, FILE *out)
 
 /* build the 128-byte ID3v1 disk structure */
 static void
-_build_v1_tag(unsigned char *buf, id3_t tag)
+_build_v1_tag(char *buf, id3_t tag)
 {
   /* FIXME: copy appropriate existing v2 tags to their v1 counterparts? */
   memset(buf, 0, 128);
@@ -574,8 +571,8 @@ id3_write(id3_t tag)
   /* old_ and new_tagsz are size of tag, including header + footer + padding */
   int old_tagsz, new_tagsz;
   int sz, written, nframes;
-  unsigned char copybuf[4096];
-  unsigned char v1buf[128];
+  char copybuf[4096];
+  char v1buf[128];
   off_t new_offset;
 #if USE_TEMPFILE
   char *tmpfname = NULL, *p;
@@ -726,7 +723,7 @@ id3_write(id3_t tag)
       if (tmpfname == NULL)
 	return -1;
       strcpy(tmpfname, tag->fname);
-      if ((p = strrchr(tmpfname, '/')) == NULL)
+      if ((p = strrchr(tmpfname, SLASH_CHAR)) == NULL)
 	p = tmpfname;
       else
 	p++;
@@ -735,8 +732,14 @@ id3_write(id3_t tag)
       tmpfname = (char *)malloc(4 + 16);
       if (tmpfname == NULL)
 	return -1;
+      /* use /tmp on real machines, just put file wherever on DOS */
+#ifdef HAVE_DOS_FILE_NAMES
+      strcpy(tmpfname, "_id3XXXXXX");
+#else
       strcpy(tmpfname, "/tmp/_id3XXXXXX");
+#endif
     }
+
     fd = xmkstemp(tmpfname);
     if (fd == -1) {
       fprintf(stderr, "id3: error opening temp file: %s\n", strerror(errno));
@@ -899,8 +902,7 @@ id3_write(id3_t tag)
 
 
 /*
- * This works like the BSD mkstemp, except that we don't unlink the
- * file, since we end up renaming it to something else.
+ * like the BSD mkstemp
  */
 static int
 xmkstemp(char *template)
