@@ -1,10 +1,10 @@
-/* Copyright (C) 1999--2002 Chris Vaill
+/* Copyright (C) 1999--2005 Chris Vaill
    This file is part of normalize.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -84,6 +84,7 @@
 extern int apply_gain_mp3(char *, double, struct signal_info *);
 extern int strncaseeq(const char *s1, const char *s2, size_t n);
 extern void progress_callback(char *prefix, float fraction_completed);
+extern char *basename(char *path);
 extern void *xmalloc(size_t size);
 
 extern char *progname;
@@ -218,8 +219,8 @@ _do_apply_gain(int read_fd, int write_fd, char *filename, double gain,
   int frames_in_buf, frames_recvd;
   int use_limiter_this_file;
 #if USE_LOOKUPTABLE
-  int min_pos_clipped; /* the minimum positive sample that gets clipped */
-  int max_neg_clipped; /* the maximum negative sample that gets clipped */
+  int min_pos_clipped = 0; /* the minimum positive sample that gets clipped */
+  int max_neg_clipped = 0; /* the maximum negative sample that gets clipped */
   int32_t *lut = NULL;
 #endif
 
@@ -352,11 +353,7 @@ _do_apply_gain(int read_fd, int write_fd, char *filename, double gain,
 
   /* initialize progress meter */
   if (verbose >= VERBOSE_PROGRESS) {
-    if (strrchr(filename, '/') != NULL) {
-      filename = strrchr(filename, '/');
-      filename++;
-    }
-    strncpy(prefix_buf, filename, 17);
+    strncpy(prefix_buf, basename(filename), 17);
     prefix_buf[17] = 0;
     progress_callback(prefix_buf, 0.0);
     last_progress = 0.0;
@@ -567,10 +564,7 @@ apply_gain(char *filename, double gain, struct signal_info *si)
    * filesystem) for a fast rename later. */
   tmpfile = (char *)xmalloc(strlen(filename) + 16);
   strcpy(tmpfile, filename);
-  if ((p = strrchr(tmpfile, '/')) == NULL)
-    p = tmpfile;
-  else
-    p++;
+  p = basename(tmpfile);
   strcpy(p, "_normXXXXXX");
   write_fd = xmkstemp(tmpfile);
   if (write_fd == -1) {
@@ -599,14 +593,19 @@ apply_gain(char *filename, double gain, struct signal_info *si)
    * We have opened the descriptors; call _do_apply_gain() to do the
    * real work.  _do_apply_gain() also closes the descriptors.
    */
-  if (_do_apply_gain(read_fd, write_fd, filename, gain, si) == -1)
+  if (_do_apply_gain(read_fd, write_fd, filename, gain, si) == -1) {
+#if USE_TEMPFILE
+    free(tmpfile);
+#endif
     return -1;
+  }
 
 #if USE_TEMPFILE
   /* move the temporary file back to the original file */
   if (xrename(tmpfile, filename) == -1) {
     fprintf(stderr, _("%s: error moving %s to %s: %s\n"), progname,
 	    tmpfile, filename, strerror(errno));
+    free(tmpfile);
     return -1;
   }
   free(tmpfile);
@@ -676,7 +675,7 @@ xrename(const char *oldpath, const char *newpath)
   if (strcmp(oldpath, newpath) == 0)
     return 0;
 
-#ifdef __EMX__
+#if defined(__EMX__) || defined(HAVE_DOS_FILE_NAMES)
   if (unlink(newpath) == -1 && errno != ENOENT)
     return -1;
 #endif
