@@ -1,10 +1,10 @@
-/* Copyright (C) 1999--2001 Chris Vaill
+/* Copyright (C) 1999--2005 Chris Vaill
    This file is part of normalize.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -87,6 +87,7 @@ extern int apply_gain(char *fname, double, struct signal_info *);
 void compute_levels(struct signal_info *sis, char **fnames, int nfiles);
 double average_levels(struct signal_info *sis, int nfiles, double threshold);
 int strncaseeq(const char *s1, const char *s2, size_t n);
+char *basename(char *path);
 void *xmalloc(size_t size);
 
 extern char version[];
@@ -137,7 +138,7 @@ Normalize volume of multiple audio files\n\
   -V, --version                display version information and exit\n\
   -h, --help                   display this help and exit\n\
 \n\
-Report bugs to <cvaill@cs.columbia.edu>.\n"), progname);
+Report bugs to <chrisvaill@gmail.com>.\n"), progname);
 }
 
 enum {
@@ -178,7 +179,7 @@ main(int argc, char *argv[])
 {
   int c, i, nfiles, ret;
   struct signal_info *sis, *psi;
-  double level, gain = 1.0, dBdiff;
+  double level = 0.0, gain = 1.0, dBdiff = 0.0;
   char **fnames, *p;
   char cbuf[32];
   struct stat st;
@@ -218,10 +219,7 @@ main(int argc, char *argv[])
 #endif
 
   /* get program name */
-  if ((progname = strrchr(argv[0], '/')) == NULL)
-    progname = argv[0];
-  else
-    progname++;
+  progname = basename(argv[0]);
   if (strlen(progname) > 16)
     progname[16] = '\0';
 
@@ -367,7 +365,7 @@ main(int argc, char *argv[])
     case 'V':
       printf("normalize %s\n", version);
       printf(_("\
-Copyright (C) 2002 Chris Vaill\n\
+Copyright (C) 2005 Chris Vaill\n\
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "));
@@ -967,7 +965,7 @@ progress_callback(char *prefix, float fraction_completed)
   time_t now, time_spent;
   unsigned int file_eta_hr, file_eta_min, file_eta_sec;
   off_t kb_done;
-  float batch_fraction;
+  float batch_fraction = 0;
   unsigned int batch_eta_hr, batch_eta_min, batch_eta_sec;
 
   if (!show_progress)
@@ -1004,15 +1002,21 @@ progress_callback(char *prefix, float fraction_completed)
       + fraction_completed * progress_info.file_sizes[progress_info.on_file];
     batch_fraction = (float)kb_done / (float)progress_info.batch_size;
     time_spent = now - progress_info.batch_start;
-    batch_eta_sec = (unsigned int)((float)time_spent / batch_fraction
-				   - (float)time_spent + 0.5);
+    if (kb_done == 0)
+      batch_eta_sec = 0;
+    else
+      batch_eta_sec = (unsigned int)((float)time_spent / batch_fraction
+				     - (float)time_spent + 0.5);
 
     batch_eta_min = batch_eta_sec / 60;
     batch_eta_sec = batch_eta_sec % 60;
     batch_eta_hr = batch_eta_min / 60;
     batch_eta_min = batch_eta_min % 60;
-    if (batch_eta_hr > 99)
+    if (batch_eta_hr > 99) {
       batch_eta_hr = 99;
+      batch_eta_min = 59;
+      batch_eta_sec = 59;
+    }
   }
 
 
@@ -1056,6 +1060,22 @@ strncaseeq(const char *s1, const char *s2, size_t n)
   return 1;
 }
 
+/*
+ * Like the SUSv2 basename, except guaranteed non-destructive, and
+ * doesn't correctly handle pathnames ending in '/'.
+ */
+char *
+basename(char *path)
+{
+  char *p;
+  p = strrchr(path, SLASH_CHAR);
+  if (p)
+    p++;
+  else
+    p = path;
+  return p;
+}
+
 void *
 xmalloc(size_t size)
 {
