@@ -62,11 +62,14 @@
 
 #include "common.h"
 
+#undef DEBUG
+
 #if USE_MAD
 extern double signal_max_power_mp3(char *filename, struct signal_info *si);
 extern int strncaseeq(const char *s1, const char *s2, size_t n);
 #endif
 extern void progress_callback(char *prefix, float fraction_completed);
+extern char *basename(char *path);
 extern void *xmalloc(size_t size);
 
 extern char *progname;
@@ -168,6 +171,9 @@ signal_max_power(char *filename, struct signal_info *si)
       return signal_max_power_mp3(filename, si);
   }
 #endif
+#if DEBUG
+  unsigned long total_frames_recvd = 0;
+#endif
 
   fhin = afOpenFile(filename, "r", NULL);
   if (fhin == AF_NULL_FILEHANDLE)
@@ -205,7 +211,13 @@ signal_max_power(char *filename, struct signal_info *si)
 
   /* set up buffer to hold 1/100 of a second worth of frames */
   windowsz = (unsigned int)(si->samples_per_sec / 100);
-  framesz = afGetFrameSize(fhin, AF_DEFAULT_TRACK, 1);
+  /* we care about the virtual frame size, not the format's particular
+     frame size, which might be zero */
+  /*framesz = afGetFrameSize(fhin, AF_DEFAULT_TRACK, 1);*/
+  framesz = si->channels * bytes_per_sample;
+  /* We use 4 bytes for 24-bit samples, adjust the frame size */
+  if (bytes_per_sample == 3)
+    framesz += si->channels;
   data_buf = (unsigned char *)xmalloc(windowsz * framesz);
 
   /* set up smoothing window buffer */
@@ -218,11 +230,7 @@ signal_max_power(char *filename, struct signal_info *si)
 
   /* initialize progress meter */
   if (verbose >= VERBOSE_PROGRESS) {
-    if (strrchr(filename, '/') != NULL) {
-      filename = strrchr(filename, '/');
-      filename++;
-    }
-    strncpy(prefix_buf, filename, 17);
+    strncpy(prefix_buf, basename(filename), 17);
     prefix_buf[17] = '\0';
     progress_callback(prefix_buf, 0.0);
     last_progress = 0.0;
@@ -252,9 +260,17 @@ signal_max_power(char *filename, struct signal_info *si)
 
     /* read a windowsz sized chunk of frames */
     frames_recvd = afReadFrames(fhin, AF_DEFAULT_TRACK, data_buf, windowsz);
-    if (frames_recvd == -1) {
+#if DEBUG
+    printf("frames: %d\n", frames_recvd);
+#endif
+    if (frames_recvd == -1)
       goto error2;
-    }
+    if (frames_recvd == 0)
+      break;
+
+#if DEBUG
+    total_frames_recvd += frames_recvd;
+#endif
 
     for (c = 0; c < si->channels; c++) {
       sums[c] = 0;
@@ -305,6 +321,10 @@ signal_max_power(char *filename, struct signal_info *si)
 
   } while (!last_window);
 
+#if DEBUG
+    printf("%lu samples read\n", total_frames_recvd * si->channels);
+#endif
+
   if (maxpow < EPSILON) {
     /*
      * Either this whole file has zero power, or was too short to ever
@@ -408,11 +428,7 @@ signal_max_power_stream(FILE *in, char *filename, struct signal_info *si)
 
   /* initialize progress meter */
   if (verbose >= VERBOSE_PROGRESS) {
-    if (strrchr(filename, '/') != NULL) {
-      filename = strrchr(filename, '/');
-      filename++;
-    }
-    strncpy(prefix_buf, filename, 17);
+    strncpy(prefix_buf, basename(filename), 17);
     prefix_buf[17] = 0;
     progress_callback(prefix_buf, 0.0);
   }
