@@ -385,6 +385,7 @@ int
 afReadFrames(AFfilehandle fh, int track, void *buffer, int frame_count)
 {
   int framesize, frames_recvd, samples_recvd, i;
+  int offset_current, bytes_remaining, frames_remaining;
   int8_t *psrc, *pdest;
   int8_t *p8;
 #ifdef WORDS_BIGENDIAN
@@ -394,6 +395,16 @@ afReadFrames(AFfilehandle fh, int track, void *buffer, int frame_count)
 
   framesize = _afGetFrameSize(fh, track, 0);
 
+  /* FIXME: need to update this for large file support */
+  offset_current = ftell(riff_stream(fh->riff));
+  bytes_remaining = fh->data_chnk.offset + fh->data_chnk.size - offset_current;
+  if (bytes_remaining < 0)
+    bytes_remaining = 0;
+  frames_remaining = bytes_remaining / framesize;
+
+  if (frames_remaining < frame_count)
+    frame_count = frames_remaining;
+
   frames_recvd = fread(buffer, framesize, frame_count, riff_stream(fh->riff));
   samples_recvd = frames_recvd * fh->fmt.channels;
 
@@ -497,7 +508,7 @@ afWriteFrames(AFfilehandle fh, int track, void *buffer, int frame_count)
     /* point to 4-byte values (source) */
     psrc = (int32_t *)buffer;
     /* point to 3-byte values (dest) */
-    pdest = (char *)buffer;
+    pdest = (int8_t *)buffer;
 
     for (i = 0; i < samp_count; i++) {
       samp = *psrc;
